@@ -1,4 +1,5 @@
 #!/bin/sh
+# shellcheck disable=SC2016,SC1004
 
 grep -wq debug /proc/cmdline && debug=1
 [ -n "$debug" ] && echo "zfs-generator: starting" >> /dev/kmsg
@@ -88,7 +89,7 @@ else
   _zfs_generator_cb() {
       dset="${1}"
       mpnt="${2}"
-      unit="sysroot$(echo "$mpnt" | sed 's;/;-;g').mount"
+      unit="sysroot$(echo "$mpnt" | tr '/' '-').mount"
 
       {
           echo "[Unit]"
